@@ -45,6 +45,13 @@ module LogStash; class JavaPipeline < AbstractPipeline
   def initialize(pipeline_config, namespaced_metric = nil, agent = nil)
     @logger = self.logger
     super pipeline_config, namespaced_metric, @logger, agent
+
+    Util::with_logging_thread_context('pipeline.id' => pipeline_id) do
+      finish_initialization
+    end
+  end
+
+  def finish_initialization
     open_queue
 
     @worker_threads = []
@@ -126,9 +133,11 @@ module LogStash; class JavaPipeline < AbstractPipeline
   def start
     # Since we start lets assume that the metric namespace is cleared
     # this is useful in the context of pipeline reloading
-    collect_stats
-    collect_dlq_stats
-    initialize_flow_metrics
+    Util::with_logging_thread_context("pipeline.id" => pipeline_id) do
+      collect_stats
+      collect_dlq_stats
+      initialize_flow_metrics
+    end
 
     @logger.debug("Starting pipeline", default_logging_keys)
 
@@ -258,6 +267,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
       @preserve_event_order = preserve_event_order?(pipeline_workers)
       batch_size = settings.get("pipeline.batch.size")
       batch_delay = settings.get("pipeline.batch.delay")
+      batch_metric_sampling = settings.get("pipeline.batch.metrics.sampling_mode")
 
       max_inflight = batch_size * pipeline_workers
 
@@ -278,6 +288,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
         "pipeline.batch.size" => batch_size,
         "pipeline.batch.delay" => batch_delay,
         "pipeline.max_inflight" => max_inflight,
+        "batch_metric_sampling" => batch_metric_sampling,
         "pipeline.sources" => pipeline_source_details)
       @logger.info("Starting pipeline", pipeline_log_params)
 
@@ -539,6 +550,7 @@ module LogStash; class JavaPipeline < AbstractPipeline
       collector.clear("stats/pipelines/#{pipeline_id}/plugins")
       collector.clear("stats/pipelines/#{pipeline_id}/events")
       collector.clear("stats/pipelines/#{pipeline_id}/flow")
+      collector.clear("stats/pipelines/#{pipeline_id}/batch")
     end
   end
 
